summaryrefslogtreecommitdiffstats
path: root/kio/kio/knfsshare.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/knfsshare.cpp')
-rw-r--r--kio/kio/knfsshare.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kio/kio/knfsshare.cpp b/kio/kio/knfsshare.cpp
index 861176c94..f0fdfce6d 100644
--- a/kio/kio/knfsshare.cpp
+++ b/kio/kio/knfsshare.cpp
@@ -33,7 +33,7 @@ public:
KNFSSharePrivate();
bool readExportsFile();
- bool tqfindExportsFile();
+ bool findExportsFile();
TQDict<bool> sharedPaths;
TQString exportsFile;
@@ -41,17 +41,17 @@ public:
KNFSSharePrivate::KNFSSharePrivate()
{
- if (tqfindExportsFile())
+ if (findExportsFile())
readExportsFile();
}
/**
* Try to tqfind the nfs config file path
* First tries the kconfig, then checks
* several well-known paths
* @return wether an 'exports' file was found.
**/
-bool KNFSSharePrivate::tqfindExportsFile() {
+bool KNFSSharePrivate::findExportsFile() {
KConfig config("knfsshare");
config.setGroup("General");
exportsFile = config.readPathEntry("exportsFile");
@@ -123,7 +123,7 @@ bool KNFSSharePrivate::readExportsFile() {
// Handle quotation marks
if ( completeLine[0] == '"' ) {
- int i = completeLine.tqfind('"',1);
+ int i = completeLine.find('"',1);
if (i == -1) {
kdError() << "KNFSShare: Parse error: Missing quotation mark: " << completeLine << endl;
continue;
@@ -131,9 +131,9 @@ bool KNFSSharePrivate::readExportsFile() {
path = completeLine.mid(1,i-1);
} else { // no quotation marks
- int i = completeLine.tqfind(' ');
+ int i = completeLine.find(' ');
if (i == -1)
- i = completeLine.tqfind('\t');
+ i = completeLine.find('\t');
if (i == -1)
path = completeLine;
@@ -180,7 +180,7 @@ bool KNFSShare::isDirectoryShared( const TQString & path ) const {
if ( path[path.length()-1] != '/' )
fixedPath += '/';
- return d->sharedPaths.tqfind(fixedPath) != 0;
+ return d->sharedPaths.find(fixedPath) != 0;
}
TQStringList KNFSShare::sharedDirectories() const {
@@ -41,17 +41,17 @@ public:
}
/**
- * Try to tqfind the nfs config file path
+ * Try to find the nfs config file path
* First tries the kconfig, then checks
* several well-known paths